@@ -7,8 +7,6 @@
 # == Author
 # SUZUKI Tetsuya <suzuki@spice-of-life.net>
 
-require 'yaml'
-require 'kconv'
 require 'tapkit/access/adapter'
 require 'tapkit/access/model'
 require 'tapkit/control/description'
@@ -40,6 +38,6 @@ require 'tapkit/control/sortordering'
 require 'tapkit/control/datasource'
 require 'tapkit/control/observer'
 require 'tapkit/control/notification'
-require 'tapkit/control/displaygroup'
+# require 'tapkit/control/displaygroup'
 
 
