@@ -13,7 +13,7 @@ module TapKit #:nodoc:
 
 		class << self
 			def new_with_name( name, model = nil, application = nil )
-				require "tapkit/access/adapters/#{name.downcase}"
+				require "tapkit/access/adapters/#{name.downcase.untaint}"
 				adapter_class(name).new(model, application)
 			end
 
