@@ -77,7 +77,7 @@ module TapKit
 		def open
 			unless open? then
 				connection = @adapter_context.adapter.connection
-				url  = connection['url']
+				url  = connection['url'].untaint
 				user = connection['user']
 				pass = connection['password']
 				@dbi = DBI.connect(url, user, pass)
