@@ -176,6 +176,19 @@ module TapKit
 				yield value
 			end
 		end
+
+		def method_missing( name, *args )
+			key = name.to_s.sub(/=$/, '')
+			if property_keys.include?(key) then
+				if /=$/ === name.to_s then
+					__send__(:[]=, key, args[0])
+				else
+					__send__(:[], key)
+				end
+			else
+				super
+			end
+		end
 	end
 
 
