@@ -5,5 +5,7 @@ create table TEST_ADAPTER (
 	TEST_STRING char(64),
 	TEST_NUMBER int,
 	TEST_DATE date,
+	TEST_TIME time,
+	TEST_TIMESTAMP timestamp,
 	primary key (TEST_ID)
 ) type=InnoDB;
